from peak_utility.number import Ordinal

class FinishingPosition(Ordinal):
    def __new__(cls, value, *, tied: bool = False): ...
    def __bool__(self) -> bool: ...
    @classmethod
    def parse(cls, value: int | str): ...
