from peak_utility.number import RepresentationalInt

class RaceClass(RepresentationalInt):
    def __new__(cls, value: str | int): ...
    def __hash__(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __gt__(self, other): ...
