from peak_utility.enumeration.parsing_enum import ParsingEnum

class Headgear(ParsingEnum):
    HOOD: int
    BLINKERS: int
    CHEEKPIECES: int
    TONGUE_TIE: int
    VISOR: int
    EYE_HOOD: int
    EYE_COVER: int
    EYE_SHIELD: int
    H = HOOD
    B = BLINKERS
    BL = BLINKERS
    C = CHEEKPIECES
    P = CHEEKPIECES
    T = TONGUE_TIE
    TT = TONGUE_TIE
    V = VISOR
    E = EYE_HOOD
    EC = EYE_COVER
    ES = EYE_SHIELD
