from .hemisphere import Hemisphere as Hemisphere
from enum import Enum

class Country(Enum):
    def __new__(cls, country_name, hemisphere): ...
    ARG = ...
    AUS = ...
    AUT = ...
    AZE = ...
    BHR = ...
    BAR = ...
    BEL = ...
    BOS = ...
    BRZ = ...
    BUL = ...
    CAN = ...
    CHI = ...
    CHN = ...
    COL = ...
    CRO = ...
    CYP = ...
    CZE = ...
    DEN = ...
    DOM = ...
    ECU = ...
    FIN = ...
    FR = ...
    GER = ...
    GB = ...
    GR = ...
    HER = ...
    HUN = ...
    IND = ...
    IRE = ...
    IRN = ...
    ITY = ...
    JAM = ...
    JPN = ...
    KEN = ...
    KOR = ...
    LEB = ...
    LTU = ...
    LUX = ...
    MAL = ...
    MEX = ...
    MOR = ...
    HOL = ...
    NZ = ...
    NOR = ...
    OM = ...
    PAK = ...
    PRY = ...
    PER = ...
    PHI = ...
    POL = ...
    POR = ...
    PR = ...
    QA = ...
    RUM = ...
    RUS = ...
    KSA = ...
    SER = ...
    SVK = ...
    SVN = ...
    SAF = ...
    SPA = ...
    SWE = ...
    SWI = ...
    SY = ...
    TRI = ...
    TUN = ...
    TUR = ...
    UAE = ...
    USA = ...
    URU = ...
    UZB = ...
    VEN = ...
    ZIM = ...
