from .going_description import GoingDescription as GoingDescription

class DirtGoingDescription(GoingDescription):
    MUDDY: int
    SLOW: int
    SLOPPY: float
    GOOD: int
    WET_FAST: float
    SEALED: int
    FAST: int
