from peak_utility.enumeration.parsing_enum import ParsingEnum

class Hemisphere(ParsingEnum):
    NORTHERN: int
    SOUTHERN: int
    N = NORTHERN
    S = SOUTHERN
    NORTH = NORTHERN
    SOUTH = SOUTHERN
