from peak_utility.enumeration.parsing_enum import ParsingEnum

class HorseExperienceLevel(ParsingEnum):
    MAIDEN: int
    NOVICE: int
    BEGINNER: int
    NOVICES = NOVICE
    BEGINNERS = BEGINNER
